summaryrefslogtreecommitdiff
path: root/libavformat/avisynth.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavformat/avisynth.c')
-rw-r--r--libavformat/avisynth.c11
1 files changed, 6 insertions, 5 deletions
diff --git a/libavformat/avisynth.c b/libavformat/avisynth.c
index a2f0550a3f..a5cf4e728a 100644
--- a/libavformat/avisynth.c
+++ b/libavformat/avisynth.c
@@ -407,13 +407,14 @@ static int avisynth_open_file(AVFormatContext *s)
avs->vi = avs_library.avs_get_video_info(avs->clip);
#ifdef USING_AVISYNTH
- /* libav only supports AviSynth 2.6 on Windows. Since AvxSynth
- * identifies itself as interface version 3 like 2.5.8, this
- * needs to be special-cased. */
+ /* On Windows, libav supports AviSynth interface version 6 or higher.
+ * This includes AviSynth 2.6 RC1 or higher, and AviSynth+ r1718 or higher,
+ * and excludes 2.5 and the 2.6 alphas. Since AvxSynth identifies itself
+ * as interface version 3 like 2.5.8, this needs to be special-cased. */
- if (avs_library.avs_get_version(avs->clip) == 3) {
+ if (avs_library.avs_get_version(avs->clip) < 6) {
av_log(s, AV_LOG_ERROR,
- "AviSynth 2.5.8 not supported. Please upgrade to 2.6.\n");
+ "AviSynth version is too old. Please upgrade to either AviSynth 2.6 >= RC1 or AviSynth+ >= r1718.\n");
ret = AVERROR_UNKNOWN;
goto fail;
}